betty.ancestry.presence_role package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.presence_role package

## Submodules

- betty.ancestry.presence_role.presence_roles module
  - `Attendee`
  - `Beneficiary`
  - `Celebrant`
  - `Informant`
  - `Organizer`
  - `Speaker`
  - `Subject`
  - `Unknown`
  - `Witness`

## Module contents

Provide presence roles.

betty.ancestry.presence_role.PRESENCE_ROLE_REPOSITORY: PluginRepository[PresenceRole] = <betty.plugin.entry_point.EntryPointPluginRepository object>

  The presence role plugin repository.

  Read more about Presence role plugins.

class betty.ancestry.presence_role.PresenceRole

  Bases: `Plugin`

  A person’s role at an event.

  Read more about Presence role plugins.